==> ably_flutter-1.2.0.tar.gz: test_integration/lib/test/realtime/realtime_presence_history_test.dart <==
import 'package:ably_flutter/ably_flutter.dart';
import 'package:ably_flutter_example/provisioning.dart';

import '../../config/test_config.dart';
import '../../factory/reporter.dart';
import '../../utils/data.dart';
import '../../utils/realtime.dart';

Future<Map<String, dynamic>> testRealtimePresenceHistory({
  Reporter reporter,
  Map<String, dynamic> payload,
}) async {
  reporter.reportLog('init start');
  final appKey = await provision('sandbox-');
  final logMessages = <List<String>>[];

  final options = ClientOptions.fromKey(appKey.toString())
    ..environment = 'sandbox'
    ..clientId = 'someClientId'
    ..logLevel = LogLevel.verbose
    ..logHandler =
        ({msg, exception}) => logMessages.add([msg, exception.toString()]);

  final realtime = Realtime(options: options);
  final channel = realtime.channels.get('test');

  final historyInitial = await getPresenceHistory(channel);

  // creating presence history on channel
  final realtimePresence = channel.presence;
  // single client enters channel
  await realtimePresence.enter(messagesToPublish.first[1]);
  // updates, multiple times with different messages
  for (var i = 1; i < messagesToPublish.length - 1; i++) {
    await realtimePresence.update(messagesToPublish[i][1]);
  }
  // leaves channel
  await realtimePresence.leave(messagesToPublish.last[1]);

  final historyDefault = await getPresenceHistory(channel);
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final historyLimit4 = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(limit: 4),
  );
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final historyLimit2 = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(limit: 2),
  );
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final historyForwards = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(direction: 'forwards'),
  );
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final time1 = DateTime.now();
  //TODO(tiholic) iOS fails without this delay
  // - timestamp on message retrieved from history
  // is earlier than expected when ran in CI
  await Future.delayed(TestConstants.publishToHistoryDelay);
  await realtimePresence.enter('enter-start-time');
  // TODO(tiholic) understand why tests fail without this delay
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final time2 = DateTime.now();
  await Future.delayed(TestConstants.publishToHistoryDelay);
  await realtimePresence.leave('leave-end-time');
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final historyWithStart = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(start: time1),
  );
  final historyWithStartAndEnd = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(start: time1, end: time2),
  );
  final historyAll = await getPresenceHistory(channel);

  return {
    'handle': await realtime.handle,
    'historyInitial': historyInitial,
    'historyDefault': historyDefault,
    'historyLimit4': historyLimit4,
    'historyLimit2': historyLimit2,
    'historyForwards': historyForwards,
    'historyWithStart': historyWithStart,
    'historyWithStartAndEnd': historyWithStartAndEnd,
    'historyAll': historyAll,
    'log': logMessages,
  };
}

==> ably_flutter-1.2.1.tar.gz: test_integration/lib/test/realtime/realtime_presence_history_test.dart <==
import 'package:ably_flutter/ably_flutter.dart';
import 'package:ably_flutter_example/provisioning.dart';

import '../../config/test_constants.dart';
import '../../factory/reporter.dart';
import '../../utils/data.dart';
import '../../utils/realtime.dart';

Future<Map<String, dynamic>> testRealtimePresenceHistory({
  required Reporter reporter,
  Map<String, dynamic>? payload,
}) async {
  reporter.reportLog('init start');
  final appKey = await provision('sandbox-');
  final logMessages = <List<String?>>[];

  final options = ClientOptions.fromKey(appKey.toString())
    ..environment = 'sandbox'
    ..clientId = 'someClientId'
    ..logLevel = LogLevel.verbose
    ..logHandler =
        ({msg, exception}) => logMessages.add([msg, exception.toString()]);

  final realtime = Realtime(options: options);
  final channel = realtime.channels.get('test');

  final historyInitial = await getPresenceHistory(channel);

  // creating presence history on channel
  final realtimePresence = channel.presence;
  // single client enters channel
  await realtimePresence.enter(messagesToPublish.first[1]);
  // updates, multiple times with different messages
  for (var i = 1; i < messagesToPublish.length - 1; i++) {
    await realtimePresence.update(messagesToPublish[i][1]);
  }
  // leaves channel
  await realtimePresence.leave(messagesToPublish.last[1]);

  final historyDefault = await getPresenceHistory(channel);
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final historyLimit4 = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(limit: 4),
  );
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final historyLimit2 = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(limit: 2),
  );
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final historyForwards = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(direction: 'forwards'),
  );
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final time1 = DateTime.now();
  //TODO(tiholic) iOS fails without this delay
  // - timestamp on message retrieved from history
  // is earlier than expected when ran in CI
  await Future.delayed(TestConstants.publishToHistoryDelay);
  await realtimePresence.enter('enter-start-time');
  // TODO(tiholic) understand why tests fail without this delay
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final time2 = DateTime.now();
  await Future.delayed(TestConstants.publishToHistoryDelay);
  await realtimePresence.leave('leave-end-time');
  await Future.delayed(TestConstants.publishToHistoryDelay);

  final historyWithStart = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(start: time1),
  );
  final historyWithStartAndEnd = await getPresenceHistory(
    channel,
    RealtimeHistoryParams(start: time1, end: time2),
  );
  final historyAll = await getPresenceHistory(channel);

  return {
    'handle': await realtime.handle,
    'historyInitial': historyInitial,
    'historyDefault': historyDefault,
    'historyLimit4': historyLimit4,
    'historyLimit2': historyLimit2,
    'historyForwards': historyForwards,
    'historyWithStart': historyWithStart,
    'historyWithStartAndEnd': historyWithStartAndEnd,
    'historyAll': historyAll,
    'log': logMessages,
  };
}
